@@ -8,7 +8,7 @@ use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -30,6 +30,23 @@ sub register_prereqs
 {
   my($self) = @_;
 
+  my $prereqs = $self->zilla->prereqs->as_string_hash;
+
+  $DB::single = 1;  
+  foreach my $phase (keys %$prereqs)
+  {
+    foreach my $type (keys %{ $prereqs->{$phase} })
+    {
+      if(defined $prereqs->{$phase}->{$type}->{'Alien::Base'})
+      {
+        $self->zilla->register_prereqs({
+          type => $type,
+          phase => $phase,
+        }, 'Alien::Base' => '0.036' );
+      }
+    }
+  }
+
   if(my $file = first { $_->name eq 'alienfile' } @{ $self->zilla->files })
   {
     require Alien::Build;
@@ -37,7 +54,7 @@ sub register_prereqs
     $alienfile->spew($file->content);
     my $build = Alien::Build->load($alienfile);
 
-    my $ab_version = '0.15';
+    my $ab_version = '0.19';
 
     if($self->_installer eq 'Makefile.PL')
     {
@@ -156,7 +173,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
